@@ -63,7 +63,6 @@ LearnerClassifSVM = R6Class("LearnerClassifSVM",
     .train = function(task) {
       pv = self$param_set$get_values(tags = "train")
       data = as_numeric_matrix(task$data(cols = task$feature_names))
-      self$state$feature_names = colnames(data)
 
       invoke(e1071::svm,
         x = data,
@@ -76,7 +75,6 @@ LearnerClassifSVM = R6Class("LearnerClassifSVM",
     .predict = function(task) {
       pv = self$param_set$get_values(tags = "predict")
       newdata = as_numeric_matrix(ordered_features(task, self))
-      newdata = newdata[, self$state$feature_names, drop = FALSE]
       p = invoke(predict, self$model,
         newdata = newdata,
         probability = (self$predict_type == "prob"), .args = pv)
